"""WebSocket client implementation per RFC 6455."""

from .client import WebSocketClient
from .frames import WSFrame, OpCode, CloseCode, WSFrameBuilder
from .state_machine import WebSocketStateMachine, WSState, WSEvent
from .handshake import WebSocketHandshake

__all__ = [
    "WebSocketClient",
    "WSFrame",
    "OpCode",
    "CloseCode",
    "WSFrameBuilder",
    "WebSocketStateMachine",
    "WSState",
    "WSEvent",
    "WebSocketHandshake",
]
