"""Email protocol clients (SMTP and IMAP)."""

from .smtp import SMTPClient, SMTPState, SMTPResponseCode
from .imap import IMAPClient, IMAPState, IMAPCommandBuilder, IMAPSequenceSet

__all__ = [
    "SMTPClient",
    "SMTPState",
    "SMTPResponseCode",
    "IMAPClient",
    "IMAPState",
    "IMAPCommandBuilder",
    "IMAPSequenceSet",
]
